@@ -1,6 +1,6 @@
 ## Here we write all auxiliar functions for the Point Process
 ## Regression Model
-is.Ppr <- function(yuimaPpr){is(yuimaPpr,"yuima.Ppr")}
+is.PPR <- function(yuimaPPR){is(yuimaPPR,"yuima.PPR")}
 
 Internal.LogLikPPR <- function(param,my.envd1=NULL,
                                my.envd2=NULL,my.envd3=NULL){
@@ -18,8 +18,8 @@ Internal.LogLikPPR <- function(param,my.envd1=NULL,
   # if(is.nan(Integr1)){
   #   Integr1 <- -10^6
   # }
-  if(length(my.envd3$YUIMA.PPR@Ppr@counting.var)>0){
-    cond1 <- my.envd3$YUIMA.PPR@model@solve.variable %in% my.envd3$YUIMA.PPR@Ppr@counting.var
+  if(length(my.envd3$YUIMA.PPR@PPR@counting.var)>0){
+    cond1 <- my.envd3$YUIMA.PPR@model@solve.variable %in% my.envd3$YUIMA.PPR@PPR@counting.var
     cond2 <- diff(as.numeric(my.envd3$YUIMA.PPR@data@original.data[,cond1]))
     #Integr2<- sum(log(IntLambda[-1][cond2!=0]),na.rm=TRUE)
     Integr2 <- sum(log(IntLambda[cond2!=0]),na.rm=TRUE)
@@ -37,7 +37,8 @@ Internal.LogLikPPR <- function(param,my.envd1=NULL,
     oldpar <- my.envd1$oldpar
   }
   ret <- -logLik/sum(cond2,na.rm=TRUE)#+sum((param-oldpar)^2*param^2)/2
-  cat("\n ",logLik, param)
+  # line 40 necessary for the development of the cod
+  #cat("\n ",logLik, param)
   
   #assign("oldpar",param,envir = my.envd1)
   
@@ -45,47 +46,47 @@ Internal.LogLikPPR <- function(param,my.envd1=NULL,
 }
 
 
-quasiLogLik.Ppr <- function(yuimaPpr, parLambda=list(), method=method, fixed = list(),
+quasiLogLik.PPR <- function(yuimaPPR, parLambda=list(), method=method, fixed = list(),
                             lower, upper, call, ...){
 
-  yuimaPpr->yuimaPPr
+  yuimaPPR->yuimaPPR
   parLambda->param
-  gfun<-yuimaPPr@gFun@formula
+  gfun<-yuimaPPR@gFun@formula
 
-  gfun<-yuimaPPr@gFun@formula
+  gfun<-yuimaPPR@gFun@formula
 
-  dimIntegr <- length(yuimaPPr@Kernel@Integrand@IntegrandList)
+  dimIntegr <- length(yuimaPPR@Kernel@Integrand@IntegrandList)
   Integrand2 <- character(length=dimIntegr)
   for(i in c(1:dimIntegr)){
-    Integrand1 <- as.character(yuimaPPr@Kernel@Integrand@IntegrandList[[i]])
-    timeCond <- paste0(" * (",yuimaPPr@Kernel@variable.Integral@var.time," < ",yuimaPPr@Kernel@variable.Integral@upper.var,")")
+    Integrand1 <- as.character(yuimaPPR@Kernel@Integrand@IntegrandList[[i]])
+    timeCond <- paste0(" * (",yuimaPPR@Kernel@variable.Integral@var.time," < ",yuimaPPR@Kernel@variable.Integral@upper.var,")")
     Integrand2[i] <-paste0(Integrand1,timeCond)
   }
 
-  Integrand2<- matrix(Integrand2,yuimaPPr@Kernel@Integrand@dimIntegrand[1],yuimaPPr@Kernel@Integrand@dimIntegrand[2])
+  Integrand2<- matrix(Integrand2,yuimaPPR@Kernel@Integrand@dimIntegrand[1],yuimaPPR@Kernel@Integrand@dimIntegrand[2])
 
 
-  for(j in c(1:yuimaPPr@Kernel@Integrand@dimIntegrand[2])){
-    Integrand2[,j]<-paste0(Integrand2[,j]," * d",yuimaPPr@Kernel@variable.Integral@var.dx[j])
+  for(j in c(1:yuimaPPR@Kernel@Integrand@dimIntegrand[2])){
+    Integrand2[,j]<-paste0(Integrand2[,j]," * d",yuimaPPR@Kernel@variable.Integral@var.dx[j])
   }
-  colnames(Integrand2) <- paste0("d",yuimaPPr@Kernel@variable.Integral@var.dx)
+  colnames(Integrand2) <- paste0("d",yuimaPPR@Kernel@variable.Integral@var.dx)
   NamesIntegrandExpr <- as.character(matrix(colnames(Integrand2), dim(Integrand2)[1],dim(Integrand2)[2], byrow = TRUE))
   Integrand2expr<- parse(text=Integrand2)
 
-  gridTime <- time(yuimaPPr@data@original.data)
+  gridTime <- time(yuimaPPR@data@original.data)
 
-  yuimaPPr@Kernel@variable.Integral@var.dx
-  if(any(yuimaPPr@Kernel@variable.Integral@var.dx %in% yuimaPPr@model@solve.variable)){
+  yuimaPPR@Kernel@variable.Integral@var.dx
+  if(any(yuimaPPR@Kernel@variable.Integral@var.dx %in% yuimaPPR@model@solve.variable)){
     my.envd1<-new.env()
     ExistdN<-TRUE
   }else{
     ExistdN<-FALSE
   }
   Univariate<-FALSE
-  if(length(yuimaPPr@Ppr@counting.var)==1){
+  if(length(yuimaPPR@PPR@counting.var)==1){
     Univariate<-TRUE
   }
-  if(any(!(yuimaPPr@Kernel@variable.Integral@var.dx %in% yuimaPPr@model@solve.variable))){
+  if(any(!(yuimaPPR@Kernel@variable.Integral@var.dx %in% yuimaPPR@model@solve.variable))){
     my.envd2<-new.env()
     ExistdX<-TRUE
   }else{
@@ -95,7 +96,7 @@ quasiLogLik.Ppr <- function(yuimaPpr, parLambda=list(), method=method, fixed = l
 
   my.envd3 <- new.env()
   namesparam<-names(param)
-  if(!(all(namesparam %in% yuimaPPr@Ppr@allparamPpr) && length(namesparam)==length(yuimaPPr@Ppr@allparamPpr))){
+  if(!(all(namesparam %in% yuimaPPR@PPR@allparamPPR) && length(namesparam)==length(yuimaPPR@PPR@allparamPPR))){
     return(NULL)
   }
 
@@ -103,43 +104,43 @@ quasiLogLik.Ppr <- function(yuimaPpr, parLambda=list(), method=method, fixed = l
   if(ExistdN){
 
     #CountingVariable
-    for(i in c(1:length(yuimaPPr@Ppr@counting.var))){
-      cond <- yuimaPPr@model@solve.variable %in% yuimaPPr@Ppr@counting.var[i]
-      dummyData <-unique(yuimaPPr@data@original.data[,cond])[-1]
-      assign(yuimaPPr@Ppr@counting.var[i], rep(1,length(dummyData)),envir=my.envd1)
+    for(i in c(1:length(yuimaPPR@PPR@counting.var))){
+      cond <- yuimaPPR@model@solve.variable %in% yuimaPPR@PPR@counting.var[i]
+      dummyData <-unique(yuimaPPR@data@original.data[,cond])[-1]
+      assign(yuimaPPR@PPR@counting.var[i], rep(1,length(dummyData)),envir=my.envd1)
     }
     # Names expression
     assign("NamesIntgra", NamesIntegrandExpr, envir=my.envd1)
     #dN
     namedX <-NULL
     namedJumpTimeX <- NULL
-    for(i in c(1:length(yuimaPPr@Kernel@variable.Integral@var.dx))){
-      if(yuimaPPr@Kernel@variable.Integral@var.dx[i] %in% yuimaPPr@Ppr@counting.var){
-        cond <- yuimaPPr@model@solve.variable %in% yuimaPPr@Kernel@variable.Integral@var.dx[i]
-        namedX<-c(namedX,paste0("d",yuimaPPr@Kernel@variable.Integral@var.dx[i]))
-        namedJumpTimeX <-c(namedJumpTimeX,paste0("JumpTime.d",yuimaPPr@Kernel@variable.Integral@var.dx[i]))
-        dummyData <- diff(as.numeric(yuimaPPr@data@original.data[,cond]))# We consider only Jump
+    for(i in c(1:length(yuimaPPR@Kernel@variable.Integral@var.dx))){
+      if(yuimaPPR@Kernel@variable.Integral@var.dx[i] %in% yuimaPPR@PPR@counting.var){
+        cond <- yuimaPPR@model@solve.variable %in% yuimaPPR@Kernel@variable.Integral@var.dx[i]
+        namedX<-c(namedX,paste0("d",yuimaPPR@Kernel@variable.Integral@var.dx[i]))
+        namedJumpTimeX <-c(namedJumpTimeX,paste0("JumpTime.d",yuimaPPR@Kernel@variable.Integral@var.dx[i]))
+        dummyData <- diff(as.numeric(yuimaPPR@data@original.data[,cond]))# We consider only Jump
         dummyJumpTime <- gridTime[-1][dummyData!=0]
         dummyData2 <- diff(unique(cumsum(dummyData)))
         #dummyData3 <- zoo(dummyData2,order.by = dummyJumpTime)
         dummyData3 <- rep(1,length(dummyData2))
         JumpTime <- dummyJumpTime
-        assign(paste0("d",yuimaPPr@Kernel@variable.Integral@var.dx[i]), dummyData3 ,envir=my.envd1)
-        assign(paste0("JumpTime.d",yuimaPPr@Kernel@variable.Integral@var.dx[i]), dummyJumpTime ,envir=my.envd1)
+        assign(paste0("d",yuimaPPR@Kernel@variable.Integral@var.dx[i]), dummyData3 ,envir=my.envd1)
+        assign(paste0("JumpTime.d",yuimaPPR@Kernel@variable.Integral@var.dx[i]), dummyJumpTime ,envir=my.envd1)
       }
     }
     assign("namedX",namedX, envir = my.envd1)
     assign("namedJumpTimeX",namedJumpTimeX, envir = my.envd1)
-    assign("var.time",yuimaPPr@Kernel@variable.Integral@var.time,envir=my.envd1)
-    assign("t.time",yuimaPPr@Kernel@variable.Integral@upper.var,envir=my.envd1)
+    assign("var.time",yuimaPPR@Kernel@variable.Integral@var.time,envir=my.envd1)
+    assign("t.time",yuimaPPR@Kernel@variable.Integral@upper.var,envir=my.envd1)
 
     # Covariates
-    if(length(yuimaPPr@Ppr@covariates)>0){
+    if(length(yuimaPPR@PPR@covariates)>0){
       # Covariates should be identified at jump time
-      for(i in c(1:length(yuimaPPr@Ppr@covariates))){
-        cond <- yuimaPPr@model@solve.variable %in% yuimaPPr@Ppr@covariates[i]
+      for(i in c(1:length(yuimaPPR@PPR@covariates))){
+        cond <- yuimaPPR@model@solve.variable %in% yuimaPPR@PPR@covariates[i]
         condTime <- gridTime %in% my.envd1$JumpTime.dN
-        assign(yuimaPPr@Ppr@covariates[i],yuimaPPr@data@original.data[condTime,cond],envir = my.envd1)
+        assign(yuimaPPR@PPR@covariates[i],yuimaPPR@data@original.data[condTime,cond],envir = my.envd1)
       }
     }
 
@@ -151,10 +152,10 @@ quasiLogLik.Ppr <- function(yuimaPpr, parLambda=list(), method=method, fixed = l
     #Covariate
 
     #CountingVariable
-    for(i in c(1:length(yuimaPPr@Ppr@counting.var))){
-      cond <- yuimaPPr@model@solve.variable %in% yuimaPPr@Ppr@counting.var[i]
-      dummyData <-yuimaPPr@data@original.data[,cond]
-      assign(yuimaPPr@Ppr@counting.var[i], dummyData,envir=my.envd1)
+    for(i in c(1:length(yuimaPPR@PPR@counting.var))){
+      cond <- yuimaPPR@model@solve.variable %in% yuimaPPR@PPR@counting.var[i]
+      dummyData <-yuimaPPR@data@original.data[,cond]
+      assign(yuimaPPR@PPR@counting.var[i], dummyData,envir=my.envd1)
     }
 
 
@@ -167,25 +168,25 @@ quasiLogLik.Ppr <- function(yuimaPpr, parLambda=list(), method=method, fixed = l
   # construction my.envd3
 
   #Covariate
-  dimCov<-length(yuimaPPr@Ppr@covariates)
+  dimCov<-length(yuimaPPR@PPR@covariates)
   if(dimCov>0){
     for(i in c(1:dimCov)){
-      cond <- yuimaPPr@model@solve.variable %in% yuimaPPr@Ppr@covariates[i] 
-      dummyData <- yuimaPPr@data@original.data[,cond]
-      assign(yuimaPPr@Ppr@covariates[i], dummyData,envir=my.envd3)
+      cond <- yuimaPPR@model@solve.variable %in% yuimaPPR@PPR@covariates[i] 
+      dummyData <- yuimaPPR@data@original.data[,cond]
+      assign(yuimaPPR@PPR@covariates[i], dummyData,envir=my.envd3)
     }
   }
   #CountingVariable
-  for(i in c(1:length(yuimaPPr@Ppr@counting.var))){
-    cond <- yuimaPPr@model@solve.variable %in% yuimaPPr@Ppr@counting.var[i]
-    dummyData <-cumsum(c(as.numeric(yuimaPPr@data@original.data[1,cond]!=0),as.numeric(diff(yuimaPPr@data@original.data[,cond])!=0)))
-    assign(yuimaPPr@Ppr@counting.var[i], dummyData,envir=my.envd3)
+  for(i in c(1:length(yuimaPPR@PPR@counting.var))){
+    cond <- yuimaPPR@model@solve.variable %in% yuimaPPR@PPR@counting.var[i]
+    dummyData <-cumsum(c(as.numeric(yuimaPPR@data@original.data[1,cond]!=0),as.numeric(diff(yuimaPPR@data@original.data[,cond])!=0)))
+    assign(yuimaPPR@PPR@counting.var[i], dummyData,envir=my.envd3)
   }
   #time
-  assign(yuimaPPr@model@time.variable, gridTime, my.envd3)
+  assign(yuimaPPR@model@time.variable, gridTime, my.envd3)
 
   #Model
-  assign("YUIMA.PPR",yuimaPPr,envir=my.envd3)
+  assign("YUIMA.PPR",yuimaPPR,envir=my.envd3)
   assign("namesparam",namesparam,envir=my.envd3)
   assign("gfun",gfun,envir=my.envd3)
   assign("Integrand2",Integrand2,envir=my.envd3)
@@ -256,52 +257,67 @@ quasiLogLik.Ppr <- function(yuimaPpr, parLambda=list(), method=method, fixed = l
                  my.envd1=my.envd1,my.envd2=my.envd2,my.envd3=my.envd3,
                  method = method, ...)
   }
-
-
-  return(out)
+   Hessian <- tryCatch(optimHess(as.list(out$par),
+                 fn=Internal.LogLikPPR,
+                 my.envd1=my.envd1,my.envd2=my.envd2,my.envd3=my.envd3),
+                 error=function(){NULL})
+   
+   cond1 <- my.envd3$YUIMA.PPR@model@solve.variable %in% my.envd3$YUIMA.PPR@PPR@counting.var
+   cond2 <- diff(as.numeric(my.envd3$YUIMA.PPR@data@original.data[,cond1]))
+   N.jump <- sum(cond2,na.rm=TRUE)
+   if(is.null(Hessian)){
+      vcov <- matrix(NA,length(out$par),length(out$par))
+   }else{
+      vcov <- solve(Hessian)/N.jump
+   }
+   minuslog <- out$value*N.jump
+   final_res<-new("yuima.PPR.qmle", call = call, coef = out$par, fullcoef = out$par,
+                  vcov = vcov, min = minuslog, details = out, minuslogl = Internal.LogLikPPR,
+                  method = method, nobs=as.integer(N.jump), model=my.envd3$YUIMA.PPR)
+  return(final_res)
 
 }
 
 
-# quasiLogLik.Ppr <- function(yuimaPpr, parLambda=list(), method=method, fixed = list(),
+# quasiLogLik.PPR <- function(yuimaPPR, parLambda=list(), method=method, fixed = list(),
 #                             lower, upper, call, ...){
 #
-#   yuimaPpr->yuimaPPr
+#   yuimaPPR->yuimaPPR
 #   parLambda->param
-#   gfun<-yuimaPPr@gFun@formula
+#   gfun<-yuimaPPR@gFun@formula
 #
-#   dimIntegr <- length(yuimaPPr@Kernel@Integrand@IntegrandList)
+#   dimIntegr <- length(yuimaPPR@Kernel@Integrand@IntegrandList)
 #   Integrand2 <- character(length=dimIntegr)
 #   for(i in c(1:dimIntegr)){
-#     Integrand1 <- as.character(yuimaPPr@Kernel@Integrand@IntegrandList[[i]])
-#     timeCond <- paste0(" * (",yuimaPPr@Kernel@variable.Integral@var.time," < ",yuimaPPr@Kernel@variable.Integral@upper.var,")")
+#     Integrand1 <- as.character(yuimaPPR@Kernel@Integrand@IntegrandList[[i]])
+#     timeCond <- paste0(" * (",yuimaPPR@Kernel@variable.Integral@var.time," < ",yuimaPPR@Kernel@variable.Integral@upper.var,")")
 #     Integrand2[i] <-paste0(Integrand1,timeCond)
 #   }
 #
-#   Integrand2<- matrix(Integrand2,yuimaPPr@Kernel@Integrand@dimIntegrand[1],yuimaPPr@Kernel@Integrand@dimIntegrand[2])
+#   Integrand2<- matrix(Integrand2,yuimaPPR@Kernel@Integrand@dimIntegrand[1],yuimaPPR@Kernel@Integrand@dimIntegrand[2])
 #
 #
-#   for(j in c(1:yuimaPPr@Kernel@Integrand@dimIntegrand[2])){
-#     Integrand2[,j]<-paste0(Integrand2[,j]," * d",yuimaPPr@Kernel@variable.Integral@var.dx[j])
+#   for(j in c(1:yuimaPPR@Kernel@Integrand@dimIntegrand[2])){
+#     Integrand2[,j]<-paste0(Integrand2[,j]," * d",yuimaPPR@Kernel@variable.Integral@var.dx[j])
 #   }
-#   colnames(Integrand2) <- paste0("d",yuimaPPr@Kernel@variable.Integral@var.dx)
+#   colnames(Integrand2) <- paste0("d",yuimaPPR@Kernel@variable.Integral@var.dx)
 #   NamesIntegrandExpr <- as.character(matrix(colnames(Integrand2), dim(Integrand2)[1],dim(Integrand2)[2], byrow = TRUE))
 #   Integrand2expr<- parse(text=Integrand2)
 #
-#   gridTime <- time(yuimaPPr@data@original.data)
+#   gridTime <- time(yuimaPPR@data@original.data)
 #
-#   yuimaPPr@Kernel@variable.Integral@var.dx
-#   if(any(yuimaPPr@Kernel@variable.Integral@var.dx %in% yuimaPPr@model@solve.variable)){
+#   yuimaPPR@Kernel@variable.Integral@var.dx
+#   if(any(yuimaPPR@Kernel@variable.Integral@var.dx %in% yuimaPPR@model@solve.variable)){
 #     my.envd1<-new.env()
 #     ExistdN<-TRUE
 #   }else{
 #     ExistdN<-FALSE
 #   }
 #   Univariate<-FALSE
-#   if(length(yuimaPPr@Ppr@counting.var)==1){
+#   if(length(yuimaPPR@PPR@counting.var)==1){
 #     Univariate<-TRUE
 #   }
-#   if(any(!(yuimaPPr@Kernel@variable.Integral@var.dx %in% yuimaPPr@model@solve.variable))){
+#   if(any(!(yuimaPPR@Kernel@variable.Integral@var.dx %in% yuimaPPR@model@solve.variable))){
 #     my.envd2<-new.env()
 #     ExistdX<-TRUE
 #   }else{
@@ -311,7 +327,7 @@ quasiLogLik.Ppr <- function(yuimaPpr, parLambda=list(), method=method, fixed = l
 #
 #   my.envd3 <- new.env()
 #   namesparam<-names(param)
-#   if(!(all(namesparam %in% yuimaPPr@Ppr@allparamPpr) && length(namesparam)==length(yuimaPPr@Ppr@allparamPpr))){
+#   if(!(all(namesparam %in% yuimaPPR@PPR@allparamPPR) && length(namesparam)==length(yuimaPPR@PPR@allparamPPR))){
 #     return(NULL)
 #   }
 #
@@ -319,32 +335,32 @@ quasiLogLik.Ppr <- function(yuimaPpr, parLambda=list(), method=method, fixed = l
 #   if(ExistdN){
 #
 #     #CountingVariable
-#     for(i in c(1:length(yuimaPPr@Ppr@counting.var))){
-#       cond <- yuimaPPr@Ppr@counting.var[i] %in% yuimaPPr@model@solve.variable
-#       dummyData <-unique(yuimaPPr@data@original.data[,cond])[-1]
-#       assign(yuimaPPr@Ppr@counting.var[i], dummyData,envir=my.envd1)
+#     for(i in c(1:length(yuimaPPR@PPR@counting.var))){
+#       cond <- yuimaPPR@PPR@counting.var[i] %in% yuimaPPR@model@solve.variable
+#       dummyData <-unique(yuimaPPR@data@original.data[,cond])[-1]
+#       assign(yuimaPPR@PPR@counting.var[i], dummyData,envir=my.envd1)
 #     }
 #     # Names expression
 #     assign("NamesIntgra", NamesIntegrandExpr, envir=my.envd1)
 #     #dN
 #     namedX <-NULL
-#     for(i in c(1:length(yuimaPPr@Kernel@variable.Integral@var.dx))){
-#       if(yuimaPPr@Kernel@variable.Integral@var.dx[i] %in% yuimaPPr@Ppr@counting.var){
-#         cond <- yuimaPPr@model@solve.variable %in% yuimaPPr@Kernel@variable.Integral@var.dx[i]
-#         namedX<-c(namedX,paste0("d",yuimaPPr@Kernel@variable.Integral@var.dx[i]))
-#         dummyData <- diff(as.numeric(yuimaPPr@data@original.data[,cond]))# We consider only Jump
+#     for(i in c(1:length(yuimaPPR@Kernel@variable.Integral@var.dx))){
+#       if(yuimaPPR@Kernel@variable.Integral@var.dx[i] %in% yuimaPPR@PPR@counting.var){
+#         cond <- yuimaPPR@model@solve.variable %in% yuimaPPR@Kernel@variable.Integral@var.dx[i]
+#         namedX<-c(namedX,paste0("d",yuimaPPR@Kernel@variable.Integral@var.dx[i]))
+#         dummyData <- diff(as.numeric(yuimaPPR@data@original.data[,cond]))# We consider only Jump
 #         dummyJumpTime <- gridTime[-1][dummyData>0]
 #         dummyData2 <- diff(unique(cumsum(dummyData)))
 #         dummyData3 <- zoo(dummyData2,order.by = dummyJumpTime)
-#         assign(paste0("d",yuimaPPr@Kernel@variable.Integral@var.dx[i]), dummyData3 ,envir=my.envd1)
+#         assign(paste0("d",yuimaPPR@Kernel@variable.Integral@var.dx[i]), dummyData3 ,envir=my.envd1)
 #       }
 #     }
 #     assign("namedX",namedX, envir = my.envd1)
-#     assign("var.time",yuimaPPr@Kernel@variable.Integral@var.time,envir=my.envd1)
-#     assign("t.time",yuimaPPr@Kernel@variable.Integral@upper.var,envir=my.envd1)
+#     assign("var.time",yuimaPPR@Kernel@variable.Integral@var.time,envir=my.envd1)
+#     assign("t.time",yuimaPPR@Kernel@variable.Integral@upper.var,envir=my.envd1)
 #
 #     # Covariates
-#     if(length(yuimaPPr@Ppr@covariates)>1){
+#     if(length(yuimaPPR@PPR@covariates)>1){
 #       # Covariates should be identified at jump time
 #       return(NULL)
 #     }
@@ -357,10 +373,10 @@ quasiLogLik.Ppr <- function(yuimaPpr, parLambda=list(), method=method, fixed = l
 #     #Covariate
 #
 #     #CountingVariable
-#     for(i in c(1:length(yuimaPPr@Ppr@counting.var))){
-#       cond <- yuimaPPr@Ppr@counting.var[i] %in% yuimaPPr@model@solve.variable
-#       dummyData <-yuimaPPr@data@original.data[,cond]
-#       assign(yuimaPPr@Ppr@counting.var[i], dummyData,envir=my.envd1)
+#     for(i in c(1:length(yuimaPPR@PPR@counting.var))){
+#       cond <- yuimaPPR@PPR@counting.var[i] %in% yuimaPPR@model@solve.variable
+#       dummyData <-yuimaPPR@data@original.data[,cond]
+#       assign(yuimaPPR@PPR@counting.var[i], dummyData,envir=my.envd1)
 #     }
 #
 #
@@ -375,16 +391,16 @@ quasiLogLik.Ppr <- function(yuimaPpr, parLambda=list(), method=method, fixed = l
 #   #Covariate
 #
 #   #CountingVariable
-#   for(i in c(1:length(yuimaPPr@Ppr@counting.var))){
-#     cond <- yuimaPPr@Ppr@counting.var[i] %in% yuimaPPr@model@solve.variable
-#     dummyData <-yuimaPPr@data@original.data[,cond]
-#     assign(yuimaPPr@Ppr@counting.var[i], dummyData,envir=my.envd3)
+#   for(i in c(1:length(yuimaPPR@PPR@counting.var))){
+#     cond <- yuimaPPR@PPR@counting.var[i] %in% yuimaPPR@model@solve.variable
+#     dummyData <-yuimaPPR@data@original.data[,cond]
+#     assign(yuimaPPR@PPR@counting.var[i], dummyData,envir=my.envd3)
 #   }
 #   #time
-#   assign(yuimaPPr@model@time.variable, gridTime, my.envd3)
+#   assign(yuimaPPR@model@time.variable, gridTime, my.envd3)
 #
 #   #Model
-#   assign("YUIMA.PPR",yuimaPPr,envir=my.envd3)
+#   assign("YUIMA.PPR",yuimaPPR,envir=my.envd3)
 #   assign("namesparam",namesparam,envir=my.envd3)
 #   assign("gfun",gfun,envir=my.envd3)
 #   assign("Integrand2",Integrand2,envir=my.envd3)
@@ -459,47 +475,47 @@ quasiLogLik.Ppr <- function(yuimaPpr, parLambda=list(), method=method, fixed = l
 # }
 
 
-lambdaFromData <- function(yuimaPpr, PprData=NULL, parLambda=list()){
- if(is.null(PprData)){
-   PprData<-yuimaPpr@data
+lambdaFromData <- function(yuimaPPR, PPRData=NULL, parLambda=list()){
+ if(is.null(PPRData)){
+   PPRData<-yuimaPPR@data
  }else{
-  # checklambdaFromData(yuimaPpr,PprData)
+  # checklambdaFromData(yuimaPPR,PPRData)
  }
- if(!any(names(parLambda) %in% yuimaPpr@Ppr@allparamPpr)){yuima.stop("1 ...")}
- if(!any(yuimaPpr@Ppr@allparamPpr %in% names(parLambda))){yuima.stop("2 ...")}
-  Time <- index(yuimaPpr@data@zoo.data[[1]])
-  envPpr <- list()
-  dY <- paste0("d",yuimaPpr@Ppr@var.dx)
+ if(!any(names(parLambda) %in% yuimaPPR@PPR@allparamPPR)){yuima.stop("1 ...")}
+ if(!any(yuimaPPR@PPR@allparamPPR %in% names(parLambda))){yuima.stop("2 ...")}
+  Time <- index(yuimaPPR@data@zoo.data[[1]])
+  envPPR <- list()
+  dY <- paste0("d",yuimaPPR@PPR@var.dx)
   for(i in (c(1:(length(Time)-1)))){
-   envPpr[[i]]<-new.env()
-    assign(yuimaPpr@gFun@param@time.var,rep(Time[i+1],i),envir=envPpr[[i]])
-    assign(yuimaPpr@Ppr@var.dt,Time[1:i],envir=envPpr[[i]])
-    if(length(yuimaPpr@Ppr@covariates)>0){
-      for(j in c(1:length(yuimaPpr@Ppr@covariates))){
-        cond<-colnames(yuimaPpr@data@original.data)%in%yuimaPpr@Ppr@covariates[[j]]
-          assign(yuimaPpr@Ppr@covariates[[j]],
-                as.numeric(yuimaPpr@data@original.data[1:(i+1),cond]),
-                envir=envPpr[[i]])
+   envPPR[[i]]<-new.env()
+    assign(yuimaPPR@gFun@param@time.var,rep(Time[i+1],i),envir=envPPR[[i]])
+    assign(yuimaPPR@PPR@var.dt,Time[1:i],envir=envPPR[[i]])
+    if(length(yuimaPPR@PPR@covariates)>0){
+      for(j in c(1:length(yuimaPPR@PPR@covariates))){
+        cond<-colnames(yuimaPPR@data@original.data)%in%yuimaPPR@PPR@covariates[[j]]
+          assign(yuimaPPR@PPR@covariates[[j]],
+                as.numeric(yuimaPPR@data@original.data[1:(i+1),cond]),
+                envir=envPPR[[i]])
       }
     }
-    for(j in c(1:length(yuimaPpr@Ppr@counting.var))){
-      cond<-colnames(yuimaPpr@data@original.data)%in%yuimaPpr@Ppr@counting.var[[j]]
-      assign(yuimaPpr@Ppr@counting.var[[j]],
-             as.numeric(yuimaPpr@data@original.data[1:(i+1),cond]),
-             envir=envPpr[[i]])
+    for(j in c(1:length(yuimaPPR@PPR@counting.var))){
+      cond<-colnames(yuimaPPR@data@original.data)%in%yuimaPPR@PPR@counting.var[[j]]
+      assign(yuimaPPR@PPR@counting.var[[j]],
+             as.numeric(yuimaPPR@data@original.data[1:(i+1),cond]),
+             envir=envPPR[[i]])
     }
 
-    for(j in c(1:length(yuimaPpr@Ppr@var.dx))){
-      cond<-c(colnames(yuimaPpr@data@original.data),yuimaPpr@Ppr@var.dt)%in%c(yuimaPpr@Ppr@var.dx,yuimaPpr@Ppr@var.dt)[[j]]
+    for(j in c(1:length(yuimaPPR@PPR@var.dx))){
+      cond<-c(colnames(yuimaPPR@data@original.data),yuimaPPR@PPR@var.dt)%in%c(yuimaPPR@PPR@var.dx,yuimaPPR@PPR@var.dt)[[j]]
       if(any(cond[-length(cond)])){
-      assign(paste0("d",yuimaPpr@Ppr@var.dx[[j]]),
-             diff(as.numeric(yuimaPpr@data@original.data[1:(i+1),cond[-length(cond)]])),
-             envir=envPpr[[i]])
+      assign(paste0("d",yuimaPPR@PPR@var.dx[[j]]),
+             diff(as.numeric(yuimaPPR@data@original.data[1:(i+1),cond[-length(cond)]])),
+             envir=envPPR[[i]])
       }
       if(tail(cond,n=1L)){
-        assign(paste0("d",yuimaPpr@Ppr@var.dx[[j]]),
+        assign(paste0("d",yuimaPPR@PPR@var.dx[[j]]),
                as.numeric(diff(Time[1:(i+1),cond[-length(cond)]])),
-               envir=envPpr[[i]])
+               envir=envPPR[[i]])
       }
     }
   }
@@ -510,19 +526,19 @@ lambdaFromData <- function(yuimaPpr, PprData=NULL, parLambda=list()){
     return(parse(text = dum))
   }
 
-  IntegKern <- lapply(yuimaPpr@Kernel@Integrand@IntegrandList,IntKernExpr,dY)
-  Integrator <- t(as.matrix(eval(parse(text=dY[1]),envir=envPpr[[length(envPpr)]])))
+  IntegKern <- lapply(yuimaPPR@Kernel@Integrand@IntegrandList,IntKernExpr,dY)
+  Integrator <- t(as.matrix(eval(parse(text=dY[1]),envir=envPPR[[length(envPPR)]])))
   if(length(dY)>1){
     for(i in c(2:length(dY))){
       Integrator <- rbind(Integrator,
-                          t(as.matrix(eval(parse(text=dY[1]),envir=envPpr[[length(envPpr)]]))))
+                          t(as.matrix(eval(parse(text=dY[1]),envir=envPPR[[length(envPPR)]]))))
     }
   }
-  assign("Integrator",Integrator,envir=envPpr[[length(envPpr)]])
-  assign("Nlamb",length(yuimaPpr@Ppr@counting.var),envir=envPpr[[length(envPpr)]])
-  res<-aux.lambdaFromData(param = unlist(parLambda), gFun=yuimaPpr@gFun,
-    Kern =IntegKern, intensityParm = yuimaPpr@Ppr@allparamPpr,
-    envPpr)
+  assign("Integrator",Integrator,envir=envPPR[[length(envPPR)]])
+  assign("Nlamb",length(yuimaPPR@PPR@counting.var),envir=envPPR[[length(envPPR)]])
+  res<-aux.lambdaFromData(param = unlist(parLambda), gFun=yuimaPPR@gFun,
+    Kern =IntegKern, intensityParm = yuimaPPR@PPR@allparamPPR,
+    envPPR)
   return(res)
 }
 # my.lapply <- function (X, FUN, ...){
@@ -534,26 +550,26 @@ myfun3<-function(X,Kern){
                              Y = X), higher = (TRUE == "array")))}
 dumFun2<-function(X,Y){list2env(Y,envir=X)}
 
-aux.lambdaFromData <-function(param, gFun, Kern, intensityParm, envPpr,logLikelihood = FALSE){
-  lapply(envPpr,FUN=dumFun2,Y=as.list(param))
-  lastEnv <- tail(envPpr,n=1L)[[1]]
+aux.lambdaFromData <-function(param, gFun, Kern, intensityParm, envPPR,logLikelihood = FALSE){
+  lapply(envPPR,FUN=dumFun2,Y=as.list(param))
+  lastEnv <- tail(envPPR,n=1L)[[1]]
   # gFunVect<- t(simplify2array(my.lapply(gFun@formula, FUN=DumFun,
   #            Y = lastEnv), higher = (TRUE == "array")))
 
   gFunVect<- matrix(unlist(lapply(gFun@formula, FUN=DumFun,
      Y = lastEnv)),nrow=lastEnv$Nlamb,byrow=TRUE)
-  # IntKer<- simplify2array(my.lapply(envPpr,function(my.env){
+  # IntKer<- simplify2array(my.lapply(envPPR,function(my.env){
   #   t(simplify2array(my.lapply(Kern, FUN=DumFun,
   #             Y = my.env), higher = (TRUE == "array")))}),
   #   higher = (TRUE == "array")
   #   )
-  # IntKer<- simplify2array(my.lapply(envPpr,myfun3,Kern=Kern),
+  # IntKer<- simplify2array(my.lapply(envPPR,myfun3,Kern=Kern),
   #                         higher = (TRUE == "array")
   # )
 
-  # IntKer<- matrix(unlist(my.lapply(envPpr,myfun3,Kern=Kern)),
+  # IntKer<- matrix(unlist(my.lapply(envPPR,myfun3,Kern=Kern)),
   #        nrow=1,byrow=TRUE)
-  IntKer<- matrix(unlist(lapply(envPpr,myfun3,Kern=Kern)),
+  IntKer<- matrix(unlist(lapply(envPPR,myfun3,Kern=Kern)),
               nrow=lastEnv$Nlamb)
   # lambda <- gFunVect+cbind(0,IntKer)
   lambda <- gFunVect+IntKer
@@ -611,3 +627,6 @@ aux.lambdaFromData <-function(param, gFun, Kern, intensityParm, envPpr,logLikeli
 }
 
 DumFun<- function(X,Y){eval(X,envir=Y)}
+
+
+
